@@ -12,7 +12,7 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2018-11-30 16:48:45 +0800 (Fri, 30 Nov 2018) $
+# $Date: 2018-11-30 17:48:45 +0900 (週五, 30 十一月 2018) $
 # $Revision: 11286 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
@@ -114,7 +114,7 @@ class LocalCacheProvider(singletonmixin.Singleton):
 localCache = LocalCacheProvider.getInstance()
 
 def attachSettings(settingsLocals, services=(
-                    'queue', 'mail', 'logging', 'browser', 'storage'),
+                    'queue', 'mail', 'logging', 'storage'),
                    serviceSettings=None,
                    loggingFile=None, loggingLevel=None,
                    cache=False, cacheDir=None):
