@@ -80,9 +80,10 @@ def attachSettings(settingsLocals, backends, preferred, config):
         'RAVEN_CONFIG': {
             'dsn': hostInfo.info['SENTRY_DSN'],
         },
-        'MIDDLEWARE_CLASSES': settingsLocals.get('MIDDLEWARE_CLASSES', ()) + [
+        'MIDDLEWARE_CLASSES': \
+            list(settingsLocals.get('MIDDLEWARE_CLASSES', ()) + [
             ('raven.contrib.django.raven_compat.middleware.'
-             'SentryResponseErrorIdMiddleware',),
+             'SentryResponseErrorIdMiddleware'),
         ],
     })
 
