@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11310 2018-12-13 07:40:43Z Lavender $
+# $Id: views.py 11326 2019-01-08 18:50:45Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-12-13 15:40:43 +0800 (??, 13 ??? 2018) $
-# $Revision: 11310 $ 
+# $Date: 2019-01-09 03:50:45 +0900 (週三, 09 一月 2019) $
+# $Revision: 11326 $ 
 
 import json
 import logging
@@ -78,7 +78,7 @@ CATHAYBK_CUP = 'cathaybk-cup' # /cathaybk-cup/checkxml/
     
 class SuccessResponseView(SuccessResponseView):
     def get_shipping_address(self, basket):
-        return PaymentDetailsView.get_shipping_address(self, basket)
+        return _PaymentDetailsView.get_shipping_address(self, basket)
 
 # patch
 from oscar.apps.checkout import views
